<?php
include 'auth_check.php'; // Include verificarea autentificării
include 'config.php'; // Include configurația bazei de date

// Pregătim variabila pentru categoriile disponibile
$categories = [];
if ($result = $conn->query("SELECT id, name FROM categories")) {
    while ($row = $result->fetch_assoc()) {
        $categories[] = $row;
    }
    $result->free();
}

// Procesăm formularul
$message = '';
$message_type = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['add'])) {
        $category_id = $_POST['category_id'];
        $name = $_POST['name'];
        $pret_unitar_intrare = isset($_POST['pret_unitar_intrare']) && $_POST['pret_unitar_intrare'] !== '' ? $_POST['pret_unitar_intrare'] : null;
        $pret_unitar_iesire = $_POST['pret_unitar_iesire'];
        $unitate_masura = $_POST['unitate_masura'];
        $dimensiune = isset($_POST['dimensiune']) && $_POST['dimensiune'] !== '' ? $_POST['dimensiune'] : null;

        // Validare simplă
        if (!empty($category_id) && !empty($name) && !empty($pret_unitar_iesire) && !empty($unitate_masura)) {
            // Pregătește și execută interogarea de inserare
            $stmt = $conn->prepare("INSERT INTO materials (category_id, name, pret_unitar_intrare, pret_unitar_iesire, unitate_masura, dimensiune) VALUES (?, ?, ?, ?, ?, ?)");
            $stmt->bind_param("issdsi", $category_id, $name, $pret_unitar_intrare, $pret_unitar_iesire, $unitate_masura, $dimensiune);

            if ($stmt->execute()) {
                header("Location: manage_materials.php?message=success");
                exit();
            } else {
                $message = "Eroare: " . $stmt->error;
                $message_type = "error";
            }

            $stmt->close();
        } else {
            $message = "Te rog să completezi toate câmpurile obligatorii.";
            $message_type = "error";
        }
    }

    if (isset($_POST['edit'])) {
        $id = $_POST['id'];
        $category_id = $_POST['category_id'];
        $name = $_POST['name'];
        $pret_unitar_intrare = isset($_POST['pret_unitar_intrare']) && $_POST['pret_unitar_intrare'] !== '' ? $_POST['pret_unitar_intrare'] : null;
        $pret_unitar_iesire = $_POST['pret_unitar_iesire'];
        $unitate_masura = $_POST['unitate_masura'];
        $dimensiune = isset($_POST['dimensiune']) && $_POST['dimensiune'] !== '' ? $_POST['dimensiune'] : null;

        // Validare simplă
        if (!empty($category_id) && !empty($name) && !empty($pret_unitar_iesire) && !empty($unitate_masura)) {
            // Pregătește și execută interogarea de actualizare
            $stmt = $conn->prepare("UPDATE materials SET category_id = ?, name = ?, pret_unitar_intrare = ?, pret_unitar_iesire = ?, unitate_masura = ?, dimensiune = ? WHERE id = ?");
            $stmt->bind_param("issdsii", $category_id, $name, $pret_unitar_intrare, $pret_unitar_iesire, $unitate_masura, $dimensiune, $id);

            if ($stmt->execute()) {
                $message = "Materialul a fost actualizat cu succes.";
                $message_type = "success";
            } else {
                $message = "Eroare: " . $stmt->error;
                $message_type = "error";
            }

            $stmt->close();
        } else {
            $message = "Te rog să completezi toate câmpurile obligatorii.";
            $message_type = "error";
        }
    }
}

// Șterge materialul
if (isset($_GET['delete'])) {
    $id = intval($_GET['delete']);

    if ($stmt = $conn->prepare("DELETE FROM materials WHERE id = ?")) {
        $stmt->bind_param("i", $id);

        if ($stmt->execute()) {
            $message = "Materialul a fost șters cu succes.";
            $message_type = "success";
        } else {
            $message = "Eroare: " . $stmt->error;
            $message_type = "error";
        }

        $stmt->close();
    }
}

// Obține materialele existente
$materials = [];
if ($result = $conn->query("SELECT m.id, m.name, m.pret_unitar_intrare, m.pret_unitar_iesire, m.unitate_masura, m.dimensiune, c.name AS category, m.category_id FROM materials m JOIN categories c ON m.category_id = c.id")) {
    while ($row = $result->fetch_assoc()) {
        $materials[] = $row;
    }
    $result->free();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
<title>Gestionare Materiale</title>
<style>
/* Include aici CSS-ul tău */
body {
    font-family: 'Arial', sans-serif;
    margin: 0;
    padding: 0;
    background-color: #f0f4f8;
    display: flex;
    justify-content: center;
    align-items: flex-start;
    height: 100vh;
    overflow: auto;
}
.container {
    width: 100%;
    max-width: 1100px;
    background-color: #ffffff;
    padding: 30px;
    border-radius: 10px;
    box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
    overflow: hidden;
}
h1 {
    margin-top: 0;
    color: #333;
    font-size: 24px;
    border-bottom: 2px solid #4CAF50;
    padding-bottom: 10px;
}
/* Stilizare generală pentru formular */
form {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
    margin-bottom: 30px;
}

label {
    margin-right: 10px;
    font-weight: bold;
    color: #555;
}

input[type="text"], input[type="number"], select {
    margin-right: 10px;
    padding: 10px;
    box-sizing: border-box;
    border: 1px solid #ddd;
    border-radius: 5px;
}

.input-category, .edit-category {
    width: 130px;
}

.input-name, .edit-name {
    width: 130px;
}

.input-price-intrare, .edit-pret-intrare {
    width: 60px;
}

.input-price-iesire, .edit-pret-iesire {
    width: 60px;
}

.input-unitate-masura, .edit-unitate-masura {
    width: 50px;
}

.input-dimensiune, .edit-dimensiune {
    width: 60px;
}

input[type="submit"] {
    background-color: #4CAF50;
    color: white;
    border: none;
    cursor: pointer;
    padding: 10px 15px;
    border-radius: 5px;
    margin-left: 10px;
}

input[type="submit"]:hover {
    background-color: #45a049;
}

.message {
    padding: 15px;
    margin-bottom: 20px;
    border-radius: 5px;
    color: #fff;
    text-align: center;
}

.message.success {
    background-color: #4CAF50;
}

.message.error {
    background-color: #f44336;
}

.scroll-container {
    max-height: 400px;
    overflow-y: auto;
    margin-bottom: 20px;
}

table {
    width: 100%;
    border-collapse: collapse;
    table-layout: fixed;
}

table, th, td {
    border: 1px solid #ddd;
}

th, td {
    padding: 12px;
    text-align: left;
    color: #333;
    word-wrap: break-word;
}

th {
    background-color: #4CAF50;
    color: white;
}

.actions button {
    background-color: #f44336;
    border: none;
    color: white;
    padding: 8px 12px;
    cursor: pointer;
    border-radius: 5px;
    margin-right: 5px;
    width: 80px; /* Ajustează dimensiunea butonului */
}

.actions .edit-btn {
    background-color: #4CAF50;
}

.actions .save-btn, .actions .cancel-btn {
    background-color: #2196F3;
}

.actions .delete-btn {
    background-color: #f44336;
}

.actions button.hidden {
    display: none;
}

.actions button:hover {
    opacity: 0.9;
}

.no-data {
    text-align: center;
    color: #999;
    margin-top: 20px;
}

.back-link {
    display: block;
    text-align: center;
    margin-top: 20px;
}

.back-link a {
    text-decoration: none;
    color: #4CAF50;
    font-weight: bold;
}

.back-link a:hover {
    text-decoration: underline;
}

.editable {
    cursor: pointer;
}

.hidden {
    display: none;
}

/* CSS pentru a controla dimensiunea coloanelor tabelului */
table th:nth-child(1), table td:nth-child(1) { /* Prima coloană: Categorie */
    width: 80px;
}

table th:nth-child(2), table td:nth-child(2) { /* A doua coloană: Denumire */
    width: 170px;
}

table th:nth-child(3), table td:nth-child(3) { /* A treia coloană: Preț Unitar Intrare */
    width: 20px;
}

table th:nth-child(4), table td:nth-child(4) { /* A patra coloană: Preț Unitar Iesire */
    width: 20px;
}

table th:nth-child(5), table td:nth-child(5) { /* A cincea coloană: Unitate de Măsură */
    width: 10px;
}

table th:nth-child(6), table td:nth-child(6) { /* A șasea coloană: Dimensiune */
    width: 10px;
}

table th:nth-child(7), table td:nth-child(7) { /* A șaptea coloană: Acțiuni */
    width: 78px;
}
</style>
</head>
<body>
<div class="container">
<?php if (!empty($message)): ?>
<div class="message <?php echo $message_type; ?>">
<?php echo htmlspecialchars($message); ?>
</div>
<?php endif; ?>
<?php if (isset($_GET['message']) && $_GET['message'] == 'success'): ?>
<div class="message success">Materialul a fost adăugat cu succes.</div>
<?php endif; ?>
<h1>Adaugă Material</h1>
<form method="post" action="">
    <label for="category_id">Categorie:</label>
    <select id="category_id" name="category_id" class="input-category" required>
        <option value="">Alege o categorie</option>
        <?php foreach ($categories as $category): ?>
            <option value="<?php echo $category['id']; ?>"><?php echo htmlspecialchars($category['name']); ?></option>
        <?php endforeach; ?>
    </select>
    <label for="name">Denumire:</label>
    <input type="text" id="name" name="name" class="input-name" required>
    <label for="pret_unitar_intrare">PU INT:</label>
    <input type="number" id="pret_unitar_intrare" name="pret_unitar_intrare" class="input-price-intrare" step="0.01">
    <label for="pret_unitar_iesire">PU IES:</label>
    <input type="number" id="pret_unitar_iesire" name="pret_unitar_iesire" class="input-price-iesire" step="0.01" required>
    <label for="unitate_masura">UM:</label>
    <input type="text" id="unitate_masura" name="unitate_masura" class="input-unitate-masura" required>
    <label for="dimensiune">Dimensiune:</label>
    <input type="number" id="dimensiune" name="dimensiune" class="input-dimensiune">
    <input type="submit" name="add" value="Adaugă">
</form>

<h1>Materiale Existente</h1>
<div class="scroll-container">
<?php if (!empty($materials)): ?>
<table>
<thead>
<tr>
<th>Categorie</th>
<th>Denumire</th>
<th>PU INT</th>
<th>PU IES</th>
<th>UM</th>
<th>DMS</th>
<th>Acțiuni</th>
</tr>
</thead>
<tbody>
<?php foreach ($materials as $material): ?>
<tr data-id="<?php echo $material['id']; ?>">
<td>
<span class="category-name"><?php echo htmlspecialchars($material['category']); ?></span>
<select class="category hidden edit-category">
<?php foreach ($categories as $category): ?>
<option value="<?php echo $category['id']; ?>" <?php if ($category['id'] == $material['category_id']) echo 'selected'; ?>>
<?php echo htmlspecialchars($category['name']); ?>
</option>
<?php endforeach; ?>
</select>
</td>
<td>
<span class="name"><?php echo htmlspecialchars($material['name']); ?></span>
<input type="text" class="edit-name hidden" value="<?php echo htmlspecialchars($material['name']); ?>">
</td>
<td>
<span class="pret_unitar_intrare"><?php echo htmlspecialchars($material['pret_unitar_intrare']); ?></span>
<input type="number" class="edit-pret-intrare hidden" value="<?php echo htmlspecialchars($material['pret_unitar_intrare']); ?>" step="0.01">
</td>
<td>
<span class="pret_unitar_iesire"><?php echo htmlspecialchars($material['pret_unitar_iesire']); ?></span>
<input type="number" class="edit-pret-iesire hidden" value="<?php echo htmlspecialchars($material['pret_unitar_iesire']); ?>" step="0.01">
</td>
<td>
<span class="unitate_masura"><?php echo htmlspecialchars($material['unitate_masura']); ?></span>
<input type="text" class="edit-unitate-masura hidden" value="<?php echo htmlspecialchars($material['unitate_masura']); ?>">
</td>
<td>
<span class="dimensiune"><?php echo htmlspecialchars($material['dimensiune']); ?></span>
<input type="number" class="edit-dimensiune hidden" value="<?php echo htmlspecialchars($material['dimensiune']); ?>">
</td>
<td class="actions">
<button class="edit-btn">Editează</button>
<button class="save-btn hidden">Salvează</button>
<button class="cancel-btn hidden">Anulează</button>
<button class="delete-btn">Șterge</button>
</td>
</tr>
<?php endforeach; ?>
</tbody>
</table>
<?php else: ?>
<p class="no-data">Nu există materiale în baza de date.</p>
<?php endif; ?>
</div>

<div class="back-link">
<a href="index.php">Înapoi</a>
</div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const tableBody = document.querySelector('tbody');

    tableBody.addEventListener('click', function(event) {
        const target = event.target;
        const row = target.closest('tr');

        if (!row) return;

        if (target.classList.contains('edit-btn')) {
            row.querySelector('.category').classList.remove('hidden');
            row.querySelector('.category-name').classList.add('hidden');
            row.querySelector('.name').classList.add('hidden');
            row.querySelector('.edit-name').classList.remove('hidden');
            row.querySelector('.pret_unitar_intrare').classList.add('hidden');
            row.querySelector('.edit-pret-intrare').classList.remove('hidden');
            row.querySelector('.pret_unitar_iesire').classList.add('hidden');
            row.querySelector('.edit-pret-iesire').classList.remove('hidden');
            row.querySelector('.unitate_masura').classList.add('hidden');
            row.querySelector('.edit-unitate-masura').classList.remove('hidden');
            row.querySelector('.dimensiune').classList.add('hidden');
            row.querySelector('.edit-dimensiune').classList.remove('hidden');
            row.querySelector('.edit-btn').classList.add('hidden');
            row.querySelector('.save-btn').classList.remove('hidden');
            row.querySelector('.cancel-btn').classList.remove('hidden');
            row.querySelector('.delete-btn').classList.add('hidden');
        }

        if (target.classList.contains('save-btn')) {
            const id = row.dataset.id;
            const categoryId = row.querySelector('.category').value;
            const name = row.querySelector('.edit-name').value;
            const pret_unitar_intrare = row.querySelector('.edit-pret-intrare').value;
            const pret_unitar_iesire = row.querySelector('.edit-pret-iesire').value;
            const unitate_masura = row.querySelector('.edit-unitate-masura').value;
            const dimensiune = row.querySelector('.edit-dimensiune').value;

            fetch('update_material.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ id, category_id: categoryId, name, pret_unitar_intrare, pret_unitar_iesire, unitate_masura, dimensiune }),
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    row.querySelector('.category-name').textContent = row.querySelector('.category option:checked').textContent;
                    row.querySelector('.name').textContent = name;
                    row.querySelector('.pret_unitar_intrare').textContent = parseFloat(pret_unitar_intrare).toFixed(2);
                    row.querySelector('.pret_unitar_iesire').textContent = parseFloat(pret_unitar_iesire).toFixed(2);
                    row.querySelector('.unitate_masura').textContent = unitate_masura;
                    row.querySelector('.dimensiune').textContent = dimensiune;
                    row.querySelector('.category').classList.add('hidden');
                    row.querySelector('.category-name').classList.remove('hidden');
                    row.querySelector('.name').classList.remove('hidden');
                    row.querySelector('.edit-name').classList.add('hidden');
                    row.querySelector('.pret_unitar_intrare').classList.remove('hidden');
                    row.querySelector('.edit-pret-intrare').classList.add('hidden');
                    row.querySelector('.pret_unitar_iesire').classList.remove('hidden');
                    row.querySelector('.edit-pret-iesire').classList.add('hidden');
                    row.querySelector('.unitate_masura').classList.remove('hidden');
                    row.querySelector('.edit-unitate-masura').classList.add('hidden');
                    row.querySelector('.dimensiune').classList.remove('hidden');
                    row.querySelector('.edit-dimensiune').classList.add('hidden');
                    row.querySelector('.edit-btn').classList.remove('hidden');
                    row.querySelector('.save-btn').classList.add('hidden');
                    row.querySelector('.cancel-btn').classList.add('hidden');
                    row.querySelector('.delete-btn').classList.remove('hidden');
                } else {
                    alert('Eroare: ' + data.error);
                }
            })
            .catch(error => {
                alert('Eroare: ' + error.message);
            });
        }

        if (target.classList.contains('cancel-btn')) {
            row.querySelector('.category').classList.add('hidden');
            row.querySelector('.category-name').classList.remove('hidden');
            row.querySelector('.name').classList.remove('hidden');
            row.querySelector('.edit-name').classList.add('hidden');
            row.querySelector('.pret_unitar_intrare').classList.remove('hidden');
            row.querySelector('.edit-pret-intrare').classList.add('hidden');
            row.querySelector('.pret_unitar_iesire').classList.remove('hidden');
            row.querySelector('.edit-pret-iesire').classList.add('hidden');
            row.querySelector('.unitate_masura').classList.remove('hidden');
            row.querySelector('.edit-unitate-masura').classList.add('hidden');
            row.querySelector('.dimensiune').classList.remove('hidden');
            row.querySelector('.edit-dimensiune').classList.add('hidden');
            row.querySelector('.edit-btn').classList.remove('hidden');
            row.querySelector('.save-btn').classList.add('hidden');
            row.querySelector('.cancel-btn').classList.add('hidden');
            row.querySelector('.delete-btn').classList.remove('hidden');
        }

        if (target.classList.contains('delete-btn')) {
            if (confirm('Sigur dorești să ștergi acest material?')) {
                const id = row.dataset.id;

                fetch('delete_material.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({ id }),
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        row.remove();
                        showMessage('Materialul a fost șters cu succes.', 'success');
                    } else {
                        showMessage('Eroare: ' + data.error, 'error');
                    }
                })
                .catch(error => {
                    showMessage('Eroare: ' + error.message, 'error');
                });
            }
        }
    });

    function showMessage(message, type) {
        const messageBox = document.createElement('div');
        messageBox.textContent = message;
        messageBox.className = 'message ' + type;

        const container = document.querySelector('.container');
        container.insertBefore(messageBox, container.firstChild);

        setTimeout(() => messageBox.remove(), 5000); // Mesajul dispare după 5 secunde
    }

    const initialMessage = document.querySelector('.message');
    if (initialMessage) {
        setTimeout(() => initialMessage.remove(), 5000); // Mesajul dispare după 5 secunde
    }
});
</script>

</body>
</html>
