<?php
include 'auth_check.php'; // Include verificarea autentificării
include 'config.php'; // Include configurația bazei de date

// Procesăm formularul
$message = '';
$message_type = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['add'])) {
        $denumire = $_POST['denumire'];
        $regula = $_POST['regula'];

        // Validare simplă
        if (!empty($denumire) && !empty($regula)) {
            // Pregătește și execută interogarea de inserare
            $stmt = $conn->prepare("INSERT INTO rules (denumire, regula) VALUES (?, ?)");
            $stmt->bind_param("ss", $denumire, $regula);

            if ($stmt->execute()) {
                header("Location: manage_rules.php?message=success");
                exit();
            } else {
                $message = "Eroare: " . $stmt->error;
                $message_type = "error";
            }

            $stmt->close();
        } else {
            $message = "Te rog să completezi toate câmpurile.";
            $message_type = "error";
        }
    }

    if (isset($_POST['edit'])) {
        $id = $_POST['id'];
        $denumire = $_POST['denumire'];
        $regula = $_POST['regula'];

        // Validare simplă
        if (!empty($denumire) && !empty($regula)) {
            // Pregătește și execută interogarea de actualizare
            $stmt = $conn->prepare("UPDATE rules SET denumire = ?, regula = ? WHERE id = ?");
            $stmt->bind_param("ssi", $denumire, $regula, $id);

            if ($stmt->execute()) {
                $message = "Regula a fost actualizată cu succes.";
                $message_type = "success";
            } else {
                $message = "Eroare: " . $stmt->error;
                $message_type = "error";
            }

            $stmt->close();
        } else {
            $message = "Te rog să completezi toate câmpurile.";
            $message_type = "error";
        }
    }
}

// Șterge regula
if (isset($_GET['delete'])) {
    $id = intval($_GET['delete']);

    if ($stmt = $conn->prepare("DELETE FROM rules WHERE id = ?")) {
        $stmt->bind_param("i", $id);

        if ($stmt->execute()) {
            $message = "Regula a fost ștearsă cu succes.";
            $message_type = "success";
        } else {
            $message = "Eroare: " . $stmt->error;
            $message_type = "error";
        }

        $stmt->close();
    }
}

// Obține regulile existente
$rules = [];
if ($result = $conn->query("SELECT * FROM rules")) {
    while ($row = $result->fetch_assoc()) {
        $rules[] = $row;
    }
    $result->free();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
<title>Gestionare Reguli</title>
<style>
/* Include aici CSS-ul tău */
body {
    font-family: 'Arial', sans-serif;
    margin: 0;
    padding: 0;
    background-color: #f0f4f8;
    display: flex;
    justify-content: center;
    align-items: flex-start;
    height: 100vh;
    overflow: auto;
}
.container {
    width: 100%;
    max-width: 1100px;
    background-color: #ffffff;
    padding: 30px;
    border-radius: 10px;
    box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
    overflow: hidden;
}
h1 {
    margin-top: 0;
    color: #333;
    font-size: 24px;
    border-bottom: 2px solid #4CAF50;
    padding-bottom: 10px;
}
/* Stilizare generală pentru formular */
form {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
    margin-bottom: 30px;
}

label {
    margin-right: 10px;
    font-weight: bold;
    color: #555;
}

input[type="text"], input[type="number"], select {
    margin-right: 10px;
    padding: 10px;
    box-sizing: border-box;
    border: 1px solid #ddd;
    border-radius: 5px;
}

.input-denumire, .edit-denumire {
    width: 200px;
}

.input-regula, .edit-regula {
    width: 300px;
}

input[type="submit"] {
    background-color: #4CAF50;
    color: white;
    border: none;
    cursor: pointer;
    padding: 10px 15px;
    border-radius: 5px;
    margin-left: 10px;
}

input[type="submit"]:hover {
    background-color: #45a049;
}

.message {
    padding: 15px;
    margin-bottom: 20px;
    border-radius: 5px;
    color: #fff;
    text-align: center;
}

.message.success {
    background-color: #4CAF50;
}

.message.error {
    background-color: #f44336;
}

.scroll-container {
    max-height: 500px;
    overflow-y: auto;
    margin-bottom: 20px;
}

table {
    width: 100%;
    border-collapse: collapse;
    table-layout: fixed;
}

table, th, td {
    border: 1px solid #ddd;
}

th, td {
    padding: 12px;
    text-align: left;
    color: #333;
    word-wrap: break-word;
}

th {
    background-color: #4CAF50;
    color: white;
}

.actions button {
    background-color: #f44336;
    border: none;
    color: white;
    padding: 8px 12px;
    cursor: pointer;
    border-radius: 5px;
    margin-right: 5px;
    width: 80px; /* Ajustează dimensiunea butonului */
}

.actions .edit-btn {
    background-color: #4CAF50;
}

.actions .save-btn, .actions .cancel-btn {
    background-color: #2196F3;
}

.actions .delete-btn {
    background-color: #f44336;
}

.actions button.hidden {
    display: none;
}

.actions button:hover {
    opacity: 0.9;
}

.no-data {
    text-align: center;
    color: #999;
    margin-top: 20px;
}

.back-link {
    display: block;
    text-align: center;
    margin-top: 20px;
}

.back-link a {
    text-decoration: none;
    color: #4CAF50;
    font-weight: bold;
}

.back-link a:hover {
    text-decoration: underline;
}

.editable {
    cursor: pointer;
}

.hidden {
    display: none;
}

/* CSS pentru a controla dimensiunea coloanelor tabelului */
table th:nth-child(1), table td:nth-child(1) { /* Prima coloană: Denumire */
    width: 200px;
}

table th:nth-child(2), table td:nth-child(2) { /* A doua coloană: Regula */
    width: 300px;
}

table th:nth-child(3), table td:nth-child(3) { /* A treia coloană: Acțiuni */
    width: 100px;
}
</style>
</head>
<body>
<div class="container">
<?php if (!empty($message)): ?>
<div class="message <?php echo $message_type; ?>">
<?php echo htmlspecialchars($message); ?>
</div>
<?php endif; ?>
<?php if (isset($_GET['message']) && $_GET['message'] == 'success'): ?>
<div class="message success">Regula a fost adăugată cu succes.</div>
<?php endif; ?>
<h1>Adaugă Regula</h1>
<form method="post" action="">
    <label for="denumire">Denumire:</label>
    <input type="text" id="denumire" name="denumire" class="input-denumire" required>
    <label for="regula">Regula:</label>
    <input type="text" id="regula" name="regula" class="input-regula" required>
    <input type="submit" name="add" value="Adaugă">
</form>

<h1>Reguli Existente</h1>
<div class="scroll-container">
<?php if (!empty($rules)): ?>
<table>
<thead>
<tr>
<th>Denumire</th>
<th>Regula</th>
<th>Acțiuni</th>
</tr>
</thead>
<tbody>
<?php foreach ($rules as $rule): ?>
<tr data-id="<?php echo $rule['id']; ?>">
<td>
<span class="denumire"><?php echo htmlspecialchars($rule['denumire']); ?></span>
<input type="text" class="edit-denumire hidden" value="<?php echo htmlspecialchars($rule['denumire']); ?>">
</td>
<td>
<span class="regula"><?php echo htmlspecialchars($rule['regula']); ?></span>
<input type="text" class="edit-regula hidden" value="<?php echo htmlspecialchars($rule['regula']); ?>">
</td>
<td class="actions">
<button class="edit-btn">Editează</button>
<button class="save-btn hidden">Salvează</button>
<button class="cancel-btn hidden">Anulează</button>
<button class="delete-btn">Șterge</button>
</td>
</tr>
<?php endforeach; ?>
</tbody>
</table>
<?php else: ?>
<p class="no-data">Nu există reguli în baza de date.</p>
<?php endif; ?>
</div>

<div class="back-link">
<a href="index.php">Înapoi</a>
</div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const tableBody = document.querySelector('tbody');

    tableBody.addEventListener('click', function(event) {
        const target = event.target;
        const row = target.closest('tr');

        if (!row) return;

        if (target.classList.contains('edit-btn')) {
            row.querySelector('.denumire').classList.add('hidden');
            row.querySelector('.edit-denumire').classList.remove('hidden');
            row.querySelector('.regula').classList.add('hidden');
            row.querySelector('.edit-regula').classList.remove('hidden');
            row.querySelector('.edit-btn').classList.add('hidden');
            row.querySelector('.save-btn').classList.remove('hidden');
            row.querySelector('.cancel-btn').classList.remove('hidden');
            row.querySelector('.delete-btn').classList.add('hidden');
        }

        if (target.classList.contains('save-btn')) {
            const id = row.dataset.id;
            const denumire = row.querySelector('.edit-denumire').value;
            const regula = row.querySelector('.edit-regula').value;

            fetch('update_rule.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ id, denumire, regula }),
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    row.querySelector('.denumire').textContent = denumire;
                    row.querySelector('.regula').textContent = regula;
                    row.querySelector('.denumire').classList.remove('hidden');
                    row.querySelector('.edit-denumire').classList.add('hidden');
                    row.querySelector('.regula').classList.remove('hidden');
                    row.querySelector('.edit-regula').classList.add('hidden');
                    row.querySelector('.edit-btn').classList.remove('hidden');
                    row.querySelector('.save-btn').classList.add('hidden');
                    row.querySelector('.cancel-btn').classList.add('hidden');
                    row.querySelector('.delete-btn').classList.remove('hidden');
                } else {
                    alert('Eroare: ' + data.error);
                }
            })
            .catch(error => {
                alert('Eroare: ' + error.message);
            });
        }

        if (target.classList.contains('cancel-btn')) {
            row.querySelector('.denumire').classList.remove('hidden');
            row.querySelector('.edit-denumire').classList.add('hidden');
            row.querySelector('.regula').classList.remove('hidden');
            row.querySelector('.edit-regula').classList.add('hidden');
            row.querySelector('.edit-btn').classList.remove('hidden');
            row.querySelector('.save-btn').classList.add('hidden');
            row.querySelector('.cancel-btn').classList.add('hidden');
            row.querySelector('.delete-btn').classList.remove('hidden');
        }

        if (target.classList.contains('delete-btn')) {
            if (confirm('Sigur dorești să ștergi această regulă?')) {
                const id = row.dataset.id;

                fetch('delete_rule.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({ id }),
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        row.remove();
                        showMessage('Regula a fost ștearsă cu succes.', 'success');
                    } else {
                        showMessage('Eroare: ' + data.error, 'error');
                    }
                })
                .catch(error => {
                    showMessage('Eroare: ' + error.message, 'error');
                });
            }
        }
    });

    function showMessage(message, type) {
        const messageBox = document.createElement('div');
        messageBox.textContent = message;
        messageBox.className = 'message ' + type;

        const container = document.querySelector('.container');
        container.insertBefore(messageBox, container.firstChild);

        setTimeout(() => messageBox.remove(), 5000); // Mesajul dispare după 5 secunde
    }

    const initialMessage = document.querySelector('.message');
    if (initialMessage) {
        setTimeout(() => initialMessage.remove(), 5000); // Mesajul dispare după 5 secunde
    }
});
</script>
</body>
</html>
